# Organizing Images into Albums

This example shows demonstrates how you can drop anything into the tree.

This example also shows how a customized DragZone can be applied to a JsonView to get automatic lightweight drag and drop of asynchronously loaded data.

The js is not minified so it is readable. See organizer.js. The multi image drag drop added a little complexity to the code, but hopefully it is still easy to follow.

For simplicity, there is no validation on the names you enter in the tree node editor and you can drag the same picture into an album as many times as you want.

Hold shift/control to select multiple images in the main images view. You can drag those images into the tree.